Instantiation
Objects can be created by calls of the form new("CubicBezier", ...).Slots
basePoint1:- Object of class
"Point" indicating the
position of the base point closest to the starting point. basePoint2:- Object of class
"Point" indicating the
position of the base point farthest from the starting point. start:- Object of class
"Point" ~~ end:- Object of class
"Point" ~~ metaId:- Object of class
"character" that is an XML ID
"described" by an RDF resource. This links an SBML element to an RDF
resource. RDF may appear anywhere in an SBML element,
but is usually placed inside the annotation element. notes:- Object of class
"character"
containing user-readable XHTML notes about an element. annotation:- Object of class
"character" containing
additional machine-readable information about an element, usually as RDF,
such as BioPAX. This is where application-specific data belongs. cvTerms:- Object of class
"list" containing
instances of CVTerm associated with this
element. sboTerm:- Object of class
"integer" identifying
a term in the Systems Biology Ontology (SBO).
Extends
Class "LineSegment", directly.
Class "SBase", by class "LineSegment", distance 2.Methods
- basePoint1
signature(object = "CubicBezier"): gets the basePoint1 slot - basePoint1<-
signature(object = "CubicBezier"): sets the basePoint1 slot - basePoint2
signature(object = "CubicBezier"): gets the basePoint2 slot - basePoint2<-
signature(object = "CubicBezier"): sets the basePoint2 slot