Species-class: SBML type "Species"
Description
A participant in an SBML model.Instantiation
Objects can be created by calls of the form new("Species", ...).Slots
id:- Object of class
"character" uniquely identifying this component. name:- Object of class
"character" naming this component. compartment:- Object of class
"character" identifying the
compartment in which this species is located. initialAmount:- Object of class
"numeric" indicating the
initial amount for this species (mutually exclusive with initialConcentration). initialConcentration:- Object of class
"numeric" indicating the
initial concentration for this species (mutually exclusive with initialAmount). substanceUnits:- Object of class
"character" identifying the
units for the amount of this species or the numerator of the concentration. spatialSizeUnits:- Object of class
"character" identifying the
units for the denominator of the species concentration. hasOnlySubstanceUnits:- Object of class
"logical" indicating
whether the quantity of this species is specified as an amount or a concentration. boundaryCondition:- Object of class
"logical". If TRUE,
indicates that the quantity of this species cannot be changed by a reaction. charge:- Object of class
"integer" indicating the electrical
charge of this species. constant:- Object of class
"logical" indicating whether
the quantity of this species can change. units:- Object of class
"character", deprecated. metaId:- Object of class
"character" that is an XML ID
"described" by an RDF resource. This links an SBML element to an RDF
resource. RDF may appear anywhere in an SBML element,
but is usually placed inside the annotation element. notes:- Object of class
"character"
containing user-readable XHTML notes about an element. annotation:- Object of class
"character" containing
additional machine-readable information about an element, usually as RDF,
such as BioPAX. This is where application-specific data belongs. cvTerms:- Object of class
"list" containing
instances of CVTerm associated with this
element. sboTerm:- Object of class
"integer" identifying
a term in the Systems Biology Ontology (SBO).
Extends
Class "SBase", directly.Methods
- id
signature(object = "Species"): gets the id slot - id<-
signature(object = "Species"): sets the id slot - name
signature(object = "Species"): gets the name slot - name<-
signature(object = "Species"): sets the name slot - boundaryCondition
signature(object = "Species"): gets the boundaryCondition slot - boundaryCondition<-
signature(object = "Species"): sets the boundaryCondition slot - charge
signature(object = "Species"): gets the charge slot - charge<-
signature(object = "Species"): sets the charge slot - compartment
signature(object = "Species"): gets the compartment slot - compartment<-
signature(object = "Species"): sets the compartment slot - constant
signature(object = "Species"): gets the constant slot - constant<-
signature(object = "Species"): sets the constant slot - units
signature(object = "Species"): gets the constant slot - units<-
signature(object = "Species"): sets the constant slot - hasOnlySubstanceUnits
signature(object = "Species"): gets the hasOnlySubstanceUnits slot - hasOnlySubstanceUnits<-
signature(object = "Species"): sets the hasOnlySubstanceUnits slot - initialAmount
signature(object = "Species"): gets the initialAmount slot - initialAmount<-
signature(object = "Species"): sets the initialAmount slot - initialConcentration
signature(object = "Species"): gets the initialConcentration slot - initialConcentration<-
signature(object = "Species"): sets the initialConcentration slot - spatialSizeUnits
signature(object = "Species"): gets the spatialSizeUnits slot - spatialSizeUnits<-
signature(object = "Species"): sets the spatialSizeUnits slot - substanceUnits
signature(object = "Species"): gets the substanceUnits slot - substanceUnits<-
signature(object = "Species"): sets the substanceUnits slot